@@ -7,14 +7,13 @@
 # Created Time:  2022-4-25 10:17:34
 # Description: 有关 ppt 的自动化操作
 #############################################
-from office.lib.utils.except_utils import except_dec
-
-from office.core.PPTType import MainPPT
-
-mainPPT = MainPPT()
+# from office.lib.utils.except_utils import except_dec
+# from office.core.PPTType import MainPPT
 
+# mainPPT = MainPPT()
 
+import poppt
 # todo：输入文件路径
 # @except_dec()
 def ppt2pdf(path: str):
-    mainPPT.ppt2pdf(path)
+    poppt.ppt2pdf(path)
