@@ -1,7 +1,3 @@
-# from office.core.WeChatType import MainWeChat
-#
-# mainwx = MainWeChat()
-
 import PyOfficeRobot
 
 
@@ -9,5 +5,9 @@ def send_message(who, message):
     PyOfficeRobot.chat.send_message(who, message)
 
 
+def chat_by_keywords(who, keywords):
+    PyOfficeRobot.chat.chat_by_keywords(who, keywords)
+
+
 def send_file(who, file):
     PyOfficeRobot.file.send_file(who, file)
