@@ -8,7 +8,7 @@ class TestImage(unittest.TestCase):
         add_watermark(file='./test_files/images/0816.jpg', mark='python-office')
 
     def test_down4img(self):
-        down4img(url='https://www.python-office.com/api/img-cdn/python-office/find_excel_data/group.jpg')
+        down4img(url='https://www.python-office.com/api/img-cdn/python-office/find_excel_data/group.jpg',output_path=r'D:\download\xunlei')
 
     # def test_img2Cartoon(self):
     #     img2Cartoon()
